@@ -5,21 +5,6 @@ library(modeldata)
 
 set.seed(1234)
 
-test_that("tunable", {
-  rec <-
-    recipe(~., data = mtcars) %>%
-    step_nearmiss(all_predictors(), under_ratio = 1)
-  rec_param <- tunable.step_nearmiss(rec$steps[[1]])
-  expect_equal(rec_param$name, c("under_ratio", "neighbors"))
-  expect_true(all(rec_param$source == "recipe"))
-  expect_true(is.list(rec_param$call_info))
-  expect_equal(nrow(rec_param), 2)
-  expect_equal(
-    names(rec_param),
-    c("name", "call_info", "source", "component", "component_id")
-  )
-})
-
 test_that("basic usage", {
   rec1 <- recipe(class ~ x + y, data = circle_example) %>%
     step_nearmiss(class)
@@ -34,6 +19,18 @@ test_that("basic usage", {
   expect_warning(prep(rec1), NA)
 })
 
+test_that("bake method errors when needed non-standard role columns are missing", {
+  rec <- recipe(class ~ x + y, data = circle_example) %>%
+    step_nearmiss(class, skip = FALSE) %>%
+    add_role(class, new_role = "potato") %>%
+    update_role_requirements(role = "potato", bake = FALSE)
+
+  trained <- prep(rec, training = circle_example, verbose = FALSE)
+
+  expect_error(bake(trained, new_data = circle_example[, -3]),
+               class = "new_data_missing_column")
+})
+
 test_that("printing", {
   rec <- recipe(class ~ x + y, data = circle_example) %>%
     step_nearmiss(class)
@@ -238,3 +235,31 @@ test_that("empty printing", {
 
   expect_snapshot(rec)
 })
+
+test_that("tunable", {
+  rec <- recipe(~., data = mtcars) %>%
+    step_nearmiss(all_predictors())
+  rec_param <- tunable.step_nearmiss(rec$steps[[1]])
+  expect_equal(rec_param$name, c("under_ratio", "neighbors"))
+  expect_true(all(rec_param$source == "recipe"))
+  expect_true(is.list(rec_param$call_info))
+  expect_equal(nrow(rec_param), 2)
+  expect_equal(
+    names(rec_param),
+    c("name", "call_info", "source", "component", "component_id")
+  )
+})
+
+test_that("tunable is setup to works with extract_parameter_set_dials works", {
+  rec <- recipe(~., data = mtcars) %>%
+    step_nearmiss(
+      all_predictors(),
+      under_ratio = hardhat::tune(),
+      neighbors = hardhat::tune()
+    )
+
+  params <- extract_parameter_set_dials(rec)
+
+  expect_s3_class(params, "parameters")
+  expect_identical(nrow(params), 2L)
+})
