@@ -12,21 +12,6 @@ test_that("ratio deprecation", {
   )
 })
 
-test_that("tunable", {
-  rec <-
-    recipe(~., data = mtcars) %>%
-    step_upsample(all_predictors())
-  rec_param <- tunable.step_upsample(rec$steps[[1]])
-  expect_equal(rec_param$name, c("over_ratio"))
-  expect_true(all(rec_param$source == "recipe"))
-  expect_true(is.list(rec_param$call_info))
-  expect_equal(nrow(rec_param), 1)
-  expect_equal(
-    names(rec_param),
-    c("name", "call_info", "source", "component", "component_id")
-  )
-})
-
 test_that("basic usage", {
   rec1 <- recipe(~., data = circle_example) %>%
     step_upsample(class)
@@ -41,6 +26,18 @@ test_that("basic usage", {
   expect_warning(prep(rec1), NA)
 })
 
+test_that("bake method errors when needed non-standard role columns are missing", {
+  rec <- recipe(class ~ x + y, data = circle_example) %>%
+    step_upsample(class, skip = FALSE) %>%
+    add_role(class, new_role = "potato") %>%
+    update_role_requirements(role = "potato", bake = FALSE)
+
+  trained <- prep(rec, training = circle_example, verbose = FALSE)
+
+  expect_error(bake(trained, new_data = circle_example[, -3]),
+               class = "new_data_missing_column")
+})
+
 test_that("printing", {
   rec <- recipe(~., data = circle_example) %>%
     step_upsample(class)
@@ -230,3 +227,74 @@ test_that("empty printing", {
 
   expect_snapshot(rec)
 })
+
+test_that("case_weights", {
+  circle_example_cw <- circle_example %>%
+    mutate(weights = frequency_weights(rep(0:1, c(200, 200))))
+
+  rec1_p <- recipe(~., data = circle_example_cw) %>%
+    step_upsample(class, over_ratio = 2) %>%
+    prep()
+
+  exp_count <- circle_example_cw %>%
+    filter(as.integer(weights) == 1) %>%
+    count(class) %>%
+    pull(n) %>%
+    max()
+
+  rec_count <- bake(rec1_p, new_data = NULL) %>%
+    count(class) %>%
+    pull(n)
+
+  expect_true(all(exp_count * 2 == rec_count))
+
+  expect_snapshot(rec1_p)
+
+  # ignore importance weights
+  circle_example_cw <- circle_example %>%
+    mutate(weights = importance_weights(rep(0:1, c(200, 200))))
+
+  rec1_p <- recipe(~., data = circle_example_cw) %>%
+    step_upsample(class) %>%
+    prep()
+
+  exp_count <- circle_example_cw %>%
+    count(class) %>%
+    pull(n) %>%
+    max()
+
+  rec_count <- bake(rec1_p, new_data = NULL) %>%
+    count(class) %>%
+    pull(n)
+
+  expect_true(all(exp_count == rec_count))
+
+  expect_snapshot(rec1_p)
+})
+
+test_that("tunable", {
+  rec <- recipe(~., data = mtcars) %>%
+    step_upsample(all_predictors())
+  rec_param <- tunable.step_upsample(rec$steps[[1]])
+  expect_equal(rec_param$name, c("over_ratio"))
+  expect_true(all(rec_param$source == "recipe"))
+  expect_true(is.list(rec_param$call_info))
+  expect_equal(nrow(rec_param), 1)
+  expect_equal(
+    names(rec_param),
+    c("name", "call_info", "source", "component", "component_id")
+  )
+})
+
+test_that("tunable is setup to works with extract_parameter_set_dials works", {
+  rec <- recipe(~., data = mtcars) %>%
+    step_upsample(
+      all_predictors(),
+      over_ratio = hardhat::tune()
+    )
+
+  params <- extract_parameter_set_dials(rec)
+
+  expect_s3_class(params, "parameters")
+  expect_identical(nrow(params), 1L)
+})
